@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2023 Antonio Diaz Diaz.
+   Copyright (C) 2005-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -102,13 +102,6 @@ bool Basic_buffer::blank( const long line ) const
   }
 
 
-bool Basic_buffer::one_character() const
-  {
-  return ( data[0].size() == 1 &&
-           ( lines() == 1 || ( lines() == 2 && data[1].empty() ) ) );
-  }
-
-
 int Basic_buffer::operator[]( const Point & p ) const
   {
   if( p.col < 0 || p.col >= characters( p.line ) ) return -1;
@@ -272,21 +265,23 @@ bool Basic_buffer::pdelb( const Point & p1, const Point & p2 )
   }
 
 
+// Keep in sync with Window_vector::change_case.
+//
 bool Basic_buffer::capitalize( const Point & p1, const Point & p2 )
   {
   bool change = false;
-  bool prev_is_alnum = false;
+  bool prev_is_whitespace = true;
   if( p1 < p2 && pisvalid( p1 ) && pisvalid( p2 ) )
     for( Point p = p1; p < p2; pnext( p ) )
       {
       const unsigned char ch = data[p.line][p.col];
-      if( prev_is_alnum )
-        { if( ISO_8859::isupper( ch ) )
-            { data[p.line][p.col] = ISO_8859::tolower( ch ); change = true; } }
-      else
+      if( prev_is_whitespace )
         { if( ISO_8859::islower( ch ) )
             { data[p.line][p.col] = ISO_8859::toupper( ch ); change = true; } }
-      prev_is_alnum = ISO_8859::isalnum_( ch );
+      else
+        { if( ISO_8859::isupper( ch ) )
+            { data[p.line][p.col] = ISO_8859::tolower( ch ); change = true; } }
+      prev_is_whitespace = ISO_8859::isspace( ch );
       }
   return change;
   }
@@ -324,9 +319,9 @@ bool Basic_buffer::to_uppercase( const Point & p1, const Point & p2 )
 bool Basic_buffer::pisbow( const Point & p ) const
   {
   Point p1 = p;
-  int ch = (*this)[p];
-  return ( ch >= 0 && ISO_8859::isalnum_( ch ) &&
-           ( p == bol( p ) || !ISO_8859::isalnum_( ppgetc( p1 ) ) ) );
+  const int ch = (*this)[p];
+  return ch >= 0 && ISO_8859::isalnum_( ch ) &&
+         ( p == bol( p ) || !ISO_8859::isalnum_( ppgetc( p1 ) ) );
   }
 
 
@@ -334,9 +329,9 @@ bool Basic_buffer::pisbow( const Point & p ) const
 bool Basic_buffer::piseow( const Point & p ) const
   {
   Point p1 = p;
-  int ch = ppgetc( p1 );
-  return ( ch >= 0 && ISO_8859::isalnum_( ch ) &&
-           ( p == eol( p ) || !ISO_8859::isalnum_( (*this)[p] ) ) );
+  const int ch = ppgetc( p1 );
+  return ch >= 0 && ISO_8859::isalnum_( ch ) &&
+         ( p == eol( p ) || !ISO_8859::isalnum_( (*this)[p] ) );
   }
 
 
@@ -510,7 +505,7 @@ int Basic_buffer::set_to_matching_delimiter( Point & p, bool forward,
   }
 
 
-/* Search forward from 'p' for 'pattern' (Boyer-Moore algorithm)
+/* Search forwards from 'p' for 'pattern' (Boyer-Moore algorithm)
    If found, set 'p' after the substring found
 */
 bool Basic_buffer::find_text( Point & p, const std::string & text,
@@ -551,7 +546,7 @@ bool Basic_buffer::find_text( Point & p, const std::string & text,
   }
 
 
-/* Search backward from 'p-1' for 'pattern' (Boyer-Moore algorithm)
+/* Search backwards from 'p-1' for 'pattern' (Boyer-Moore algorithm)
    If found, set 'p' to the first char of the substring found
 */
 bool Basic_buffer::rfind_text( Point & p, const std::string & text, const bool icase ) const
