@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2023 Antonio Diaz Diaz.
+   Copyright (C) 2005-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 #include <vector>
 
 #include "buffer.h"
+#include "buffer_handle.h"
 #include "block.h"
 #include "rc.h"
 #include "screen.h"
@@ -28,16 +29,18 @@
 
 namespace Block {
 
+const Buffer_handle * marking_bhp = 0;
 Buffer * bufferp_ = 0, * saved_bufferp = 0;
 Point anchor_, begin_, end_, saved_begin, saved_end;
 
 
-void enable_marking( Buffer & buffer, const Point & p )
+void enable_marking( const Buffer_handle & handle, const Point & p )
   {
-  bufferp_ = &buffer; begin_ = p; anchor_ = p; end_ = Point();
+  marking_bhp = &handle; bufferp_ = &handle.buffer();
+  begin_ = p; anchor_ = p; end_ = Point();
   }
 
-bool marking() { return ( anchor_ != Point() ); }
+bool marking() { return marking_bhp != 0 && anchor_ != Point(); }
 
 } // end namespace Block
 
@@ -53,25 +56,25 @@ Point & Block::end() { return end_; }
 
 bool Block::in_block( const Buffer & buffer, const Point & p )
   {
-  return ( &buffer == bufferp_ && begin_.line >= 0 && p >= begin_ && p < end_ &&
-           ( !RC::editor_options().rectangle_mode ||
-             ( p.col >= begin_.col && p.col < end_.col ) ) );
+  return &buffer == bufferp_ && begin_.line >= 0 && p >= begin_ && p < end_ &&
+         ( !RC::editor_options().rectangle_mode ||
+           ( p.col >= begin_.col && p.col < end_.col ) );
   }
 
 
 bool Block::in_block_or_end( const Buffer & buffer, const Point & p )
   {
-  return ( &buffer == bufferp_ && begin_.line >= 0 && begin_ < end_ &&
-           p >= begin_ && p <= end_ &&
-           ( !RC::editor_options().rectangle_mode ||
-             ( p.col >= begin_.col && p.col <= end_.col ) ) );
+  return &buffer == bufferp_ && begin_.line >= 0 && begin_ < end_ &&
+         p >= begin_ && p <= end_ &&
+         ( !RC::editor_options().rectangle_mode ||
+           ( p.col >= begin_.col && p.col <= end_.col ) );
   }
 
 
 bool Block::valid()
   {
-  return ( bufferp_ != 0 && begin_.line >= 0 && begin_ < end_ &&
-           ( !RC::editor_options().rectangle_mode || begin_.col < end_.col ) );
+  return bufferp_ != 0 && begin_.line >= 0 && begin_ < end_ &&
+         ( !RC::editor_options().rectangle_mode || begin_.col < end_.col );
   }
 
 
@@ -116,13 +119,14 @@ void Block::set_end( Buffer & buffer, const Point & p )
   }
 
 
-void Block::disable_marking() { anchor_ = Point(); }
+void Block::disable_marking() { marking_bhp = 0; anchor_ = Point(); }
 
 
-bool Block::follow_marking( const Buffer & buffer, const Point & p )
+bool Block::follow_marking( const Buffer_handle & handle, const Point & p )
   {
   static Point old_p;
-  if( marking() && &buffer == bufferp_ && p != old_p )
+  if( marking() && &handle == marking_bhp && &handle.buffer() == bufferp_ &&
+      p != old_p )
     {
     if( p < anchor_ ) begin_ = p; else begin_ = anchor_;
     if( p > anchor_ ) end_ = p; else end_ = anchor_;
@@ -133,27 +137,24 @@ bool Block::follow_marking( const Buffer & buffer, const Point & p )
   }
 
 
-const char * Block::toggle_marking( Buffer & buffer, const Point & p )
+const char * Block::toggle_marking( const Buffer_handle & handle, const Point & p )
   {
   const char * const msg1 = "Selection started.";
   const char * const msg2 = "Selection finished.";
   const char * const msg3 = "Selection cleared.";
   const char * msg = 0;
   const Buffer * const old_bufferp = bufferp_;
-  if( marking() )
+  Buffer & buffer = handle.buffer();
+  if( marking() && &handle == marking_bhp && &buffer == bufferp_ )
     {
-    if( &buffer == bufferp_ )
-      {
-      if( valid() ) { disable_marking(); return msg2; }
-      else { set_block( buffer, p, p ); return msg3; }
-      }
-    else { enable_marking( buffer, p ); msg = msg1; }
+    if( valid() ) { disable_marking(); return msg2; }
+    else { set_block( buffer, p, p ); return msg3; }
     }
   else
     {
     if( in_block_or_end( buffer, p ) )
       { set_block( buffer, p, p ); msg = msg3; }
-    else { enable_marking( buffer, p ); msg = msg1; }
+    else { enable_marking( handle, p ); msg = msg1; }
     }
   if( old_bufferp ) Screen::repaint( old_bufferp );
   return msg;
