@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2023 Antonio Diaz Diaz.
+   Copyright (C) 2005-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,6 +15,8 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+class Buffer_handle;		// forward declaration
+
 namespace Block {
 
 Buffer * bufferp();
@@ -34,8 +36,8 @@ void set_begin( Buffer & buffer, const Point & p );
 void set_end( Buffer & buffer, const Point & p );
 
 void disable_marking();
-bool follow_marking( const Buffer & buffer, const Point & p );
-const char * toggle_marking( Buffer & buffer, const Point & p );
+bool follow_marking( const Buffer_handle & handle, const Point & p );
+const char * toggle_marking( const Buffer_handle & handle, const Point & p );
 
 bool copy_block( Buffer & buffer, const Point & p, const bool move = false );
 bool delete_block();
