@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2023 Antonio Diaz Diaz.
+   Copyright (C) 2005-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -187,7 +187,8 @@ bool Buffer::Options::set_rmargin( const int r )
    A non-null but empty 'namep' ("") creates an empty unnamed buffer.
 */
 Buffer::Buffer( const char * const namep, const bool read_only )
-  : backuped( false ), modified_( false ), saved( false ), crlf( false )
+  : backuped( false ), modified_( false ), saved( false ), crlf( false ),
+    existed( false )
   {
   FILE * f = 0;
   const bool valid_namep = ( namep && namep[0] );
@@ -242,6 +243,7 @@ Buffer::Buffer( const char * const namep, const bool read_only )
   if( long_line ) throw Error( "Line too long" );
   if( !file_eof ) throw Error( "Not enough memory" );
   crlf = detect_and_remove_cr();
+  existed = true;
   set_marks();
   }
 
@@ -493,8 +495,8 @@ bool Buffer::pdelb( const Point & p1, const Point & p2, const bool save_end )
 bool Buffer::pdelc( Point & p, const bool back )
   {
   Point p1 = p;
-  if( back ) return ( pprev( p ) && pdelb( p, p1, true ) );
-  return ( pnext( p1 ) && pdelb( p, p1 ) );
+  if( back ) return pprev( p ) && pdelb( p, p1, true );
+  return pnext( p1 ) && pdelb( p, p1 );
   }
 
 
