@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2023 Antonio Diaz Diaz.
+   Copyright (C) 2005-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -31,8 +31,7 @@ public:
       top_left( 0, 0 ), cursor( line, col )
     { pointer = buf.to_pointer( cursor, pcursor ); }
 
-  Buffer & buffer() { return *bufferp_; }
-  const Buffer & buffer() const { return *bufferp_; }
+  Buffer & buffer() const { return *bufferp_; }
   bool first_post() { bool b = first_post_; first_post_ = false; return b; }
   };
 
