@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2023 Antonio Diaz Diaz.
+   Copyright (C) 2005-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -760,6 +760,12 @@ int map_to_byte( const int code )
     case 0x22B1: return '>';	// succeeds under relation
     case 0x22C5: return 0xB7;	// dot operator
     case 0x23AF: return '-';	// horizontal line extension
+    case 0x2500:		// box drawings light horizontal
+    case 0x2501: return '-';	// box drawings heavy horizontal
+    case 0x2502:		// box drawings light vertical
+    case 0x2503: return '|';	// box drawings heavy vertical
+    case 0x2571: return '/';	// box drawings light diagonal upper right
+    case 0x2572: return '\\';	// box drawings light diagonal upper left
     case 0x27E8: return '<';	// mathematical left angle bracket
     case 0x27E9: return '>';	// mathematical right angle bracket
     case 0x3001: return ',';	// ideographic comma
@@ -858,6 +864,7 @@ const char * map_to_string( const int code )
     case 0x2190: return "<-";	// leftwards arrow
     case 0x2192: return "->";	// rightwards arrow
     case 0x2194: return "<->";	// left right arrow
+    case 0x21A6: return "|->";	// rightwards arrow from bar
     case 0x21B2: return "<-'";	// downwards arrow with tip leftwards
     case 0x21B3: return "`->";	// downwards arrow with tip rightwards
     case 0x21D0: return "<=";	// leftwards double arrow
@@ -871,6 +878,7 @@ const char * map_to_string( const int code )
     case 0x2265: return ">=";	// greater-than or equal to
     case 0x227C: return "<=";	// precedes or equal to
     case 0x227D: return ">=";	// succeeds or equal to
+    case 0x22A3: return "-|";	// left tack
     case 0x2639: return ":-(";	// white frowning face
     case 0x263A: return ":-)";	// white smiling face
     case 0x263B: return ":-)";	// black smiling face
@@ -964,7 +972,7 @@ bool Encoding::base64_decode( const std::string & in, std::string & out,
       }
     }
   if( idxp ) *idxp = i;
-  return ( i == in.size() );
+  return i == in.size();
   }
 
 
@@ -1001,7 +1009,7 @@ bool Encoding::quoted_printable_decode( const std::string & in,
       }
     }
   if( idxp ) *idxp = i;
-  return ( i == in.size() );
+  return i == in.size();
   }
 
 
@@ -1061,7 +1069,7 @@ unsigned char Encoding::rot13( const unsigned char ch )
     case 'x': return 'k';
     case 'y': return 'l';
     case 'z': return 'm';
-    default : return  ch;
+    default: return ch;
     }
   }
 
