@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2023 Antonio Diaz Diaz.
+   Copyright (C) 2005-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -305,15 +305,36 @@ bool ISO_8859::isupper( const unsigned char ch )
   }
 
 
-bool ISO_8859::isalpha_( const unsigned char ch )
+unsigned char ISO_8859::base_char( const unsigned char ch )
   {
-  return ( ch == '_' || ISO_8859::islower( ch ) || ISO_8859::isupper( ch ) );
-  }
-
-
-bool ISO_8859::isalnum_( const unsigned char ch )
-  {
-  return ( ( ch < 128 && std::isdigit( ch ) ) || ISO_8859::isalpha_( ch ) );
+  switch( ch )
+    {
+    case CAGRAVE: case CAACUTE: case CACIRCU: case CATILDE: case CADIAER:
+    case CARING : return 'A';
+    case CCCEDI : return 'C';
+    case CEGRAVE: case CEACUTE: case CECIRCU: case CEDIAER: return 'E';
+    case CIGRAVE: case CIACUTE: case CICIRCU: case CIDIAER: return 'I';
+    case CNTILDE: return 'N';
+    case COGRAVE: case COACUTE: case COCIRCU: case COTILDE: case CODIAER:
+    case COSTROK: return 'O';
+    case CSCARON: return 'S';
+    case CUGRAVE: case CUACUTE: case CUCIRCU: case CUDIAER: return 'U';
+    case CYACUTE: case CYDIAER: return 'Y';
+    case CZCARON: return 'Z';
+    case SAGRAVE: case SAACUTE: case SACIRCU: case SATILDE: case SADIAER:
+    case SARING : return 'a';
+    case SCCEDI : return 'c';
+    case SEGRAVE: case SEACUTE: case SECIRCU: case SEDIAER: return 'e';
+    case SIGRAVE: case SIACUTE: case SICIRCU: case SIDIAER: return 'i';
+    case SNTILDE: return 'n';
+    case SOGRAVE: case SOACUTE: case SOCIRCU: case SOTILDE: case SODIAER:
+    case SOSTROK: return 'o';
+    case SSCARON: return 's';
+    case SUGRAVE: case SUACUTE: case SUCIRCU: case SUDIAER: return 'u';
+    case SYACUTE: case SYDIAER: return 'y';
+    case SZCARON: return 'z';
+    default:      return ch;
+    }
   }
 
 
