@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2023 Antonio Diaz Diaz.
+   Copyright (C) 2005-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,25 +30,31 @@ void escapize( const unsigned char ch, std::string & out );
 
 bool islower( const unsigned char ch );
 bool isupper( const unsigned char ch );
-bool isalpha_( const unsigned char ch );
-bool isalnum_( const unsigned char ch );
+inline bool isalpha( const unsigned char ch )
+  { return islower( ch ) || isupper( ch ); }
+inline bool isalpha_( const unsigned char ch )
+  { return ch == '_' || isalpha( ch ); }
+inline bool isalnum_( const unsigned char ch )
+  { return ( ch < 128 && std::isdigit( ch ) ) || isalpha_( ch ); }
 inline bool isblank( const unsigned char ch )
-  { return ( ch == ' ' || ch == '\t' ); }
+  { return ch == ' ' || ch == '\t'; }
 inline bool isspace( const unsigned char ch )	// is 'ch' whitespace?
-  { return ( std::isspace( ch ) || ch == 0xA0 ); }
+  { return std::isspace( ch ) || ch == 0xA0; }
 
 inline bool iscntrl( const unsigned char ch )
-  { return ( ch < 32 || ( ch >= 0x7F && ch < 0xA0 ) ); }
+  { return ch < 32 || ( ch >= 0x7F && ch < 0xA0 ); }
 inline bool isgraph( const unsigned char ch )
-  { return ( !iscntrl( ch ) && ch != ' ' && ch != 0xA0 ); }
+  { return !iscntrl( ch ) && ch != ' ' && ch != 0xA0; }
 inline bool isprint( const unsigned char ch )
   { return !iscntrl( ch ); }
 
 inline bool isodigit( const unsigned char ch )	// is 'ch' an octal digit?
-  { return ( ch <= '7' && ch >= '0' ); }
+  { return ch <= '7' && ch >= '0'; }
 
 inline bool isuchar( const int c ) { return c >= 0 && c <= 255; }
 
+unsigned char base_char( const unsigned char ch );	// of equivalence class
+
 const char * control_name( const unsigned char ch );	// '^A' --> "^A"
 int controlize( int code );		// converts 'A' or 'a' into '^A'
 int decontrolize( int code );		// converts '^A' or 'a' into 'A'
@@ -57,4 +63,13 @@ unsigned char toupper( const unsigned char ch );
 void map_to_ascii( const unsigned char ch, std::string & out );
 int xvalue( const unsigned char ch );	// value of hex digit 'ch' or -1
 
+// Do ch1 and ch2 belong to the same equivalence class?
+inline bool equivalent( const unsigned char ch1, const unsigned char ch2,
+                        const bool icase = false )
+  {
+  if( !icase || !isalpha( ch1 ) || !isalpha( ch2 ) )
+    return base_char( ch1 ) == base_char( ch2 );
+  return tolower( base_char( ch1 ) ) == tolower( base_char( ch2 ) );
+  }
+
 } // end namespace ISO_8859
