@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2023 Antonio Diaz Diaz.
+   Copyright (C) 2005-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 */
 /*
    Exit status: 0 for a normal exit, 1 for environmental problems
-   (invalid command line options, I/O errors, etc), 2 to indicate an invalid
+   (invalid command-line options, I/O errors, etc), 2 to indicate an invalid
    or unreadable input file, 3 for an internal consistency error (e.g., bug)
    which caused moe to panic.
 */
@@ -43,7 +43,7 @@ namespace {
 
 const char * const     program_name = "moe";
 const char * const config_file_name = "moe.conf";
-const char * const     program_year = "2023";
+const char * const     program_year = "2024";
 const char * invocation_name = program_name;		// default value
 
 
@@ -85,7 +85,7 @@ void show_help()
                "  -n, --indent-step=<n>    number of spaces to add when indenting a block\n"
 //               "  -p, --beep               beep on errors and when cursor goes past extremes\n"
                "  -s, --search-wrap        make search wrap at end of file\n"
-               "  -u, --auto-unmark        turn off highlighting after block copy or move\n"
+               "  -u, --auto-unmark        turn off highlighting after any block operation\n"
                "  -x, --rectangle          rectangular block mode\n"
                "\nFile options:\n"
                "  -a, --auto-indent        enable auto indent\n"
@@ -97,7 +97,7 @@ void show_help()
                "  -W, --no-word-wrap       disable word wrapping\n"
                "  -2, --two-spaces         make reformat put two spaces after period\n"
                "\nExit status: 0 for a normal exit, 1 for environmental problems\n"
-               "(invalid command line options, I/O errors, etc), 2 to indicate an invalid\n"
+               "(invalid command-line options, I/O errors, etc), 2 to indicate an invalid\n"
                "or unreadable input file, 3 for an internal consistency error (e.g., bug)\n"
                "which caused moe to panic.\n"
                "\nReport bugs to bug-moe@gnu.org\n"
@@ -169,7 +169,7 @@ bool use_it_anyway( const std::string & name )
   std::fprintf( stderr, "There are errors in '%s'. Use it anyway (y/N)? ",
                 name.c_str() );
   std::fflush( stderr );
-  return ( std::tolower( std::fgetc( stdin ) ) == 'y' );
+  return std::tolower( std::fgetc( stdin ) ) == 'y';
   }
 
 
