@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2023 Antonio Diaz Diaz.
+   Copyright (C) 2005-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -55,10 +55,10 @@ void show( const std::vector< std::string > & name_vector, const int lines,
       {
       if( i == current )		// highlighted entry
         {
-        i1 = s.size();
+        i1 = s.size();			// highlight begin
         if( indicator ) ++i1;		// skip modified or crlf indicator
         s += name_vector[i];
-        i2 = s.size();
+        i2 = s.size();			// highlight end
         cursor.assign( line, std::min( i2, Screen::width() - 1 ) );
         }
       else s += name_vector[i];
@@ -127,8 +127,7 @@ void split_filename( const std::string & name,
 
   if( first > 0 ) dirname.assign( name, 0, first );	// with trailing slash
   else dirname.clear();
-  if( first < name.size() )
-    basename.assign( name, first, name.size() );
+  if( first < name.size() ) basename.assign( name, first, name.size() );
   else basename.clear();
   }
 
@@ -254,8 +253,6 @@ bool Menu::file_menu( const std::string & prompt, std::string & name )
     std::sort( name_vector.begin() + dd, name_vector.end() );
     }
   else if( !entries ) return true;
-/*  else if( entries == 1 && name_vector[0] == ".." )
-    name = dirname + name_vector[0];*/
 
   if( ( entries == 1 && ( name_vector[0] != ".." || dirname.empty() ) ) ||
       ( entries == 2 && name_vector[0] == ".." && name_vector[1][0] != '.' ) )
@@ -281,7 +278,7 @@ bool Menu::file_menu( const std::string & prompt, std::string & name )
   while( key >= 0 )
     {
     show( name_vector, lines, columns, current, cursor, top_line );
-    Screen::out_line( prompt + name, Screen::height() - 1, true );
+    Screen::out_line( prompt + name, Screen::height() - 1, true, 'r' );
     Screen::move_to( Point( line, 0 ) + cursor );
     bool valid_key = false;
     while( !valid_key )
@@ -324,7 +321,7 @@ bool Menu::file_menu( const std::string & prompt, std::string & name )
       }
     }
   Screen::restore_lines_and_cursor();
-  return ( key != -1 );
+  return key != -1;
   }
 
 
@@ -382,12 +379,13 @@ bool Menu::make_dirs( const std::string & name )
     while( i < dirname.size() && dirname[i] != '/' ) ++i;
     if( first < i )
       {
-      std::string partial( dirname, 0, i );
+      const std::string partial( dirname, 0, i );
+      const mode_t mode = S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH;
       struct stat st;
       if( stat( partial.c_str(), &st ) == 0 )
         { if( !S_ISDIR( st.st_mode ) ) return false; }
-      else if( mkdir( partial.c_str(), S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH |
-                      S_IXOTH ) != 0 && errno != EEXIST ) return false;
+      else if( mkdir( partial.c_str(), mode ) != 0 && errno != EEXIST )
+        return false;		// if EEXIST, another process created the dir
       }
     }
   return true;
@@ -416,6 +414,6 @@ bool Menu::validate_filename( std::string & name )
   // to avoid introducing control characters, don't deescapize filenames
   tilde_expansion( name );
   const std::string & basename = my_basename( name );
-  return ( basename.size() && basename != "." && basename != ".." &&
-           !append_slash_if_dir( name ) );
+  return basename.size() && basename != "." && basename != ".." &&
+         !append_slash_if_dir( name );
   }
