@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2023 Antonio Diaz Diaz.
+   Copyright (C) 2005-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -55,8 +55,8 @@ const char * help_line[] = {
   " Help Screen: Block Commands     PAGE_DN next/PAGE_UP prev",
   " ",
   " @bBLOCK@b                     @bENCODE@b                 @bREMOVE@b",
-  " ^SPACE Mark begin/end     ^O1 To Base64          ^OD Duplicate lines forward",
-  " ^KB Begin                 ^O3 To Rot-13          ^OE Duplicate lines backward",
+  " ^SPACE Mark begin/end     ^O1 To Base64          ^OD Duplicate lines forwards",
+  " ^KB Begin                 ^O3 To Rot-13          ^OE Duplicate lines backwards",
   " ^KK End                   ^O4 To Rot-47          ^OO UTF-8 out of range",
   " ^KC Copy                  ^O5 To ASCII",
   " ^KM Move                  ^O7 To UTF-8",
@@ -66,7 +66,7 @@ const char * help_line[] = {
   " ^KI Indent                ^O6 Quoted-Printable",
   " ^KU Unindent              ^O8 UTF-8",
   " ^OB Reformat paragraphs",
-  " ^OK Capitalize",
+  " ^OK Capitalize words",
   " ^OL To lowercase",
   " ^OU To uppercase",
   " ",
@@ -79,12 +79,6 @@ const char * help_line[] = {
   "",
   " Help Screen: Search             PAGE_DN next/PAGE_UP prev",
   " ",
-  " Escape sequences for special characters (search or replace (except \\ooo)):",
-  "   \\a  BEL (alert)       \\n  LF (newline)           \\\\   '\\' (backslash)",
-  "   \\b  BS  (backspace)   \\r  CR (carriage return)   \\dddd decimal code 'ddd'",
-  "   \\e  ESC (escape)      \\t  HT (tab)               \\ooo  octal code 'ooo'",
-  "   \\f  FF  (form feed)   \\v  VT (vertical tab)      \\xhh  hexadecimal code 'hh'",
-  "                                                    \\uhhhh \\Uhhhhhhhh  UTF-8",
   " Special search sequences:",
   "   \\?      matches any single char       \\^  \\$  matches beginning/end of line",
   "   \\*      matches 0 or more chars       \\<  \\>  matches beginning/end of word",
@@ -94,7 +88,8 @@ const char * help_line[] = {
   "   \\S      matches the longest possible non-empty sequence of whitespace",
   "   \\w      matches any word-constituent character",
   "   \\W      matches any character that is not a word-constituent",
-  "   \\+<ch>  matches 0 or more of <ch> (also \\[..], \\w, or \\W)",
+  "   \\=<ch>  matches one in an equivalence class; '\\=e' = '\\[e]'",
+  "   \\+<ch>  matches 0 or more of <ch> (also \\[..], \\w, \\W, or \\=<ch>)",
   " ",
   " Notes",
   "   Ranges of characters may be specified in sets with 'A-Z'",
@@ -114,6 +109,13 @@ const char * help_line[] = {
   " Notes",
   "   \\u0 may be specified as \\u\\x30 to avoid ambiguity with \\uhhhh",
   "   Octal escape sequences can't be used in the replacement string",
+  " ",
+  " Escape sequences for special characters (search or replace (except \\ooo)):",
+  "   \\a  BEL (alert)       \\n  LF (newline)           \\\\    '\\' (backslash)",
+  "   \\b  BS  (backspace)   \\r  CR (carriage return)   \\dddd decimal code 'ddd'",
+  "   \\e  ESC (escape)      \\t  HT (tab)               \\ooo  octal code 'ooo'",
+  "   \\f  FF  (form feed)   \\v  VT (vertical tab)      \\xhh  hexadecimal code 'hh'",
+  "                                                    \\uhhhh \\Uhhhhhhhh  UTF-8",
   "",
   " Help Screen: Character Set      PAGE_DN next/PAGE_UP prev",
   "  \x20   \x21   \x22   \x23   \x24   \x25   \x26   \x27   \x28   \x29   \x2A   \x2B   \x2C   \x2D   \x2E   \x2F",
