@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2023 Antonio Diaz Diaz.
+   Copyright (C) 2005-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 namespace Menu {
 
 enum { columns = 3 };
+const char * const oor_msg = "Value out of range";
 int current;		// current highlighted entry in menu
 int entries;		// number of entries in menu
 int height_;		// height in lines of menu
@@ -101,7 +102,7 @@ bool indent_step_change( Buffer & )
   int i;
   if( RC::parse_int( history.back().c_str(), i ) &&
       RC::editor_options().set_indent_step( i ) ) return true;
-  Screen::show_message( "Value out of range" ); history.pop_back();
+  Screen::show_message( oor_msg ); history.pop_back();
   return false;
   }
 
@@ -123,7 +124,7 @@ bool keep_lines_change( Buffer & )
   int i;
   if( RC::parse_int( history.back().c_str(), i ) &&
       RC::editor_options().set_keep_lines( i ) ) return true;
-  Screen::show_message( "Value out of range" ); history.pop_back();
+  Screen::show_message( oor_msg ); history.pop_back();
   return false;
   }
 
@@ -145,7 +146,7 @@ bool lmargin_change( Buffer & buffer )
   int i;
   if( RC::parse_int( history.back().c_str(), i ) &&
       buffer.options.set_lmargin( i - 1 ) ) return true;
-  Screen::show_message( "Value out of range" ); history.pop_back();
+  Screen::show_message( oor_msg ); history.pop_back();
   return false;
   }
 
@@ -167,7 +168,7 @@ bool max_windows_change( Buffer & )
   int i;
   if( RC::parse_int( history.back().c_str(), i ) &&
       RC::editor_options().set_max_windows( i ) ) return true;
-  Screen::show_message( "Value out of range" ); history.pop_back();
+  Screen::show_message( oor_msg ); history.pop_back();
   return false;
   }
 
@@ -196,7 +197,7 @@ bool rmargin_change( Buffer & buffer )
   int i;
   if( RC::parse_int( history.back().c_str(), i ) &&
       buffer.options.set_rmargin( i - 1 ) ) return true;
-  Screen::show_message( "Value out of range" ); history.pop_back();
+  Screen::show_message( oor_msg ); history.pop_back();
   return false;
   }
 
