@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2023 Antonio Diaz Diaz.
+   Copyright (C) 2005-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -235,7 +235,7 @@ bool set_option_from_code( const Arg_parser & parser, const int argind,
   else if( errcode == 2 )
     std::fprintf( stderr, "%serror: Value out of range for option '%s'\n",
                   msg, parsed_name );
-  return ( errcode == 0 );
+  return errcode == 0;
   }
 
 
@@ -301,11 +301,11 @@ bool unwanted_name( const std::string & name )
   {
   const char * const ext1[] = { "a", "o", "z", "Z", 0 };
   const char * const ext2[] = { "gz", "lz", "mo", "po", "ps", "so", "xz", 0 };
-  const char * const ext3[] = { "bmp", "bz2", "deb", "dll", "dvi", "elf",
-    "exe", "gif", "gmo", "ico", "jar", "jpg", "obj", "pbm", "pdf", "pgm",
-    "png", "pnm", "ppm", "rpm", "svg", "tar", "tgz", "tif", "tlz", "txz",
-    "wav", "xcf", "zip", "zst", 0 };
-  const char * const ext4[] = { "info", "jpeg", "lzma", "rpms", "svgz",
+  const char * const ext3[] = { "avi", "bmp", "bz2", "deb", "dll", "dvi",
+    "elf", "exe", "gif", "gmo", "ico", "jar", "jpg", "mp3", "mp4", "mpg",
+    "obj", "pbm", "pdf", "pgm", "png", "pnm", "ppm", "rpm", "svg", "tar",
+    "tgz", "tif", "tlz", "txz", "wav", "xcf", "zip", "zst", 0 };
+  const char * const ext4[] = { "docx", "info", "jpeg", "lzma", "rpms", "svgz",
     "tiff", "tzst", 0 };
   const char * const ext5[] = { "class", 0 };
   const char * const * ext[5] = { ext1, ext2, ext3, ext4, ext5 };
@@ -318,6 +318,8 @@ bool unwanted_name( const std::string & name )
     if( name[name.size()-i-2] != '.' ) continue;
     for( const char * const * p = ext[i]; *p; ++p )
       if( name.compare( name.size() - i - 1, i + 1, *p ) == 0 ) return true;
+    if( i == 0 && std::isdigit( (unsigned char)name[name.size()-1] ) )
+      return true;		// exclude man pages *.[0-9]
     break;			// compare only one extension size
     }
   return false;
@@ -624,9 +626,9 @@ int RC::process_options()
   if( read_error_found || unsupported_found )
     {
     if( read_error_found )
-      std::fputs( "warning: One or more files couldn't be read.\n", stderr );
+      std::fputs( "Warning: one or more files couldn't be read.\n", stderr );
     if( unsupported_found )
-      std::fputs( "warning: File types not supported will be ignored.\n", stderr );
+      std::fputs( "Warning: file types not supported will be ignored.\n", stderr );
     return 2;
     }
   return 0;
