@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2023 Antonio Diaz Diaz.
+   Copyright (C) 2005-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -29,13 +29,17 @@ namespace Regex {
 class Set
   {
   std::vector< unsigned char > data;		// faster than bool
-  int parsed_len_;
-  bool in;
+  int parsed_len_;				// including '[' and ']'
+  bool in;				// false if this is a complemented set
 
 public:
   explicit Set( const std::string & regex, const unsigned i0 = 0 );
-  bool includes( const unsigned char ch ) const
-    { return ( parsed_len_ > 0 && in == data[ch] ); }
+  bool includes( const unsigned char ch, const bool icase = false ) const
+    {
+    if( parsed_len_ <= 0 ) return false;
+    if( !icase || !ISO_8859::isalpha( ch ) ) return in == data[ch];
+    return in == ( data[ISO_8859::tolower( ch )] || data[ISO_8859::toupper( ch )] );
+    }
   int parsed_len() const { return parsed_len_; }
   };
 
@@ -55,6 +59,16 @@ Set::Set( const std::string & regex, const unsigned i0 )
     if( ch1 == ']' && i > i1 ) { ++i; fail = false; break; }
     if( ch1 == '\\' )
       {
+      if( i + 2 < regex.size() && regex[i+1] == '=' )	// equivalence class
+        {
+        // no range, ok if '-' is last char
+        if( i + 3 < regex.size() && regex[i+3] == '-' &&
+            ( i + 4 >= regex.size() || regex[i+4] != ']' ) ) break;
+        const unsigned char chb = ISO_8859::base_char( regex[i+2] );
+        for( int code = 0; code < 256; ++code )
+          if( chb == ISO_8859::base_char( code ) ) data[code] = true;
+        i += 2; continue;
+        }
       int len, code = ISO_8859::escape( regex, i + 1, &len );
       if( code < 0 ) break;
       ch1 = code; i += len;
@@ -109,7 +123,25 @@ inline int case_plus( const Basic_buffer & buffer, Point & p,
           if( ret == 0 ) break; else if( ret != 1 ) return 2;
           }
         const int ch2 = buffer.pgetc( p );
-        if( ch2 < 0 || !set.includes( ch2 ) ) return 1;
+        if( ch2 < 0 || !set.includes( ch2, icase ) ) return 1;
+        piece += ch2;
+        }
+      pieces.insert( pieces.begin() + ps, piece ); i = regex.size();
+      return 0;
+      }
+    if( chr == '=' )			// equivalence class
+      {
+      if( i + 1 >= regex.size() ) return 2;
+      const unsigned char chc = regex[++i];
+      for( int j = 0; ; ++j )
+        {
+        if( j >= counter )
+          {
+          const int ret = match_regex( buffer, p, regex, i + 1, pieces, icase );
+          if( ret == 0 ) break; else if( ret != 1 ) return 2;
+          }
+        const int ch2 = buffer.pgetc( p );
+        if( ch2 < 0 || !ISO_8859::equivalent( chc, ch2, icase ) ) return 1;
         piece += ch2;
         }
       pieces.insert( pieces.begin() + ps, piece ); i = regex.size();
@@ -234,10 +266,17 @@ int match_regex( const Basic_buffer & buffer, Point & p,
                 Set set( regex, i );	// set of characters to match
                 if( !set.parsed_len() ) { retval = 2; break; }
                 const int ch2 = buffer.pgetc( p );
-                if( ch2 < 0 || !set.includes( ch2 ) ) { retval = 1; break; }
+                if( ch2 < 0 || !set.includes( ch2, icase ) ) { retval = 1; break; }
                 i += set.parsed_len() - 1;
                 pieces.push_back( std::string( 1, ch2 ) );
                 } break;
+      case '=': {			// equivalence class
+                if( i + 1 >= regex.size() ) { retval = 2; break; }
+                const int ch2 = buffer.pgetc( p );
+                if( ch2 < 0 || !ISO_8859::equivalent( regex[i+1], ch2, icase ) )
+                  { retval = 1; break; }
+                ++i; pieces.push_back( std::string( 1, ch2 ) );
+                } break;
       case '+': retval = case_plus( buffer, p, regex, ++i, pieces, icase );
                 break;
       case 'S': {			// find longest matching sequence
@@ -296,7 +335,7 @@ int match_regex( const Basic_buffer & buffer, Point & p,
   if( retval )
     { p = old_p;
     if( pieces_old_size != pieces.size() ) pieces.resize( pieces_old_size ); }
-  return ( retval );
+  return retval;
   }
 
 } // end namespace Regex
@@ -434,13 +473,7 @@ bool Regex::match_filename( const std::string & regex, const std::string & name,
                 if( !set.includes( name[i2++] ) ) return false;
                 i1 += set.parsed_len() - 1;
                 } break;
-      case '\\': {
-                int len, code = ISO_8859::escape( regex, i1 + 1, &len );
-                if( code < 0 || code != (unsigned char)name[i2++] ) return false;
-                i1 += len;
-                } break;
       default: if( ch1 != (unsigned char)name[i2++] ) return false;
-               break;
       }
     }
   return i2 >= name.size();
