@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2023 Antonio Diaz Diaz.
+   Copyright (C) 2005-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -58,7 +58,7 @@ public:
   void set( const int key ) { prev = current; current = key; }
   void unset() { prev = 0; current = -1UL; }
   void shift( const int key ) { current <<= 16; current += ( key & 0xFFFF ); }
-  bool compare_prev() const { return ( prev == current ); }
+  bool compare_prev() const { return prev == current; }
   } last_key;
 
 char * line_buf_;
@@ -152,19 +152,21 @@ void remove_duplicates( std::vector< std::string > & history )
   }
 
 
-const char * alt_key_loop( int key )
+const char * alt_key_loop( int key, const bool pager_mode = false )
   {
   const char * msg = 0;
   Window & w = Window_vector::curwin();
-  w.show_status_line( ISO_8859::control_name( key ) );
-  do key = wait_kbhit(); while( key < 0 );
-  w.show_status_line();
+  if( !pager_mode )
+    { w.show_status_line( ISO_8859::control_name( key ) );
+      do key = wait_kbhit(); while( key < 0 );
+      w.show_status_line(); }
   key = ISO_8859::decontrolize( key );
   last_key.shift( key );
   if( ISO_8859::isuchar( key ) && std::isdigit( key ) )
     msg = w.goto_mark( key - '0' );
   else switch( key )
     {
+    case ' ': w.scroll_vertical( w.height() - 2 ); break;
     case 'A': w.scroll_horizontal( -8 ); break;
     case 'B': msg = w.goto_begin_of_block(); break;
     case 'C': msg = w.goto_column(); break;
@@ -181,11 +183,27 @@ const char * alt_key_loop( int key )
     case 'V': w.goto_eof(); break;
     case 'W': w.move_page( false, true ); break;
     case 'Z': w.move_page( true, true ); break;
+    default:  if( pager_mode ) show_message( rdonly_msg );
     }
   return msg;
   }
 
 
+const char * maybe_add_char( const int key )
+  {
+  Window & w = Window_vector::curwin();
+  if( !w.buffer().options.read_only ) return Window_vector::add_char( key );
+  switch( key )				// basic less emulation
+    {
+    case '/': return Window_vector::search( 6 );		// ^F
+    case 'b': w.scroll_vertical( 2 - w.height() ); return 0;
+    case 'n': return Window_vector::search( 7, true, "", 0 );	// ^G -->
+    case 'N': return Window_vector::search( 7, true, "", 1 );	// ^G <--
+    default: return alt_key_loop( key, true );
+    }
+  }
+
+
 int alternative_key( int key )
   {
   Window & w = Window_vector::curwin();
@@ -330,7 +348,7 @@ const char * control_s_loop( int key, const char * const version_msg )
     case 'P': RC::editor_options().show_code_lpos =
                 ( RC::editor_options().show_code_lpos == 2 ) ? 0 : 2;
               show_status_lines(); break;
-    case 'V': msg = version_msg; break;
+    case 'V': show_message( version_msg, false, false, true, false ); break;
     }
   return msg;
   }
@@ -797,20 +815,21 @@ void Screen::show_feedback( const std::string & s )
   {
   const int line = height_ - 1;
 
-  out_string( line, 0, s, width_ );
+  out_raw_string( line, 0, s, width_ );
   wmove( stdscr, line, std::min( (int)s.size(), width_ - 1 ) );
   wrefresh( stdscr );
   }
 
 
 int Screen::show_message( const std::string & s, const bool get_key,
-                          const bool take_cursor, const bool discard_cc )
+                          const bool take_cursor, const bool discard_cc,
+                          const bool raw )
   {
   const int line = height_ - 1;
 
   save_lines_and_cursor( line, 1 );
 
-  out_string( line, 0, s, width_ );
+  raw ? out_raw_string( line, 0, s, width_ ) : out_string( line, 0, s, width_ );
   wmove( stdscr, line, std::min( (int)s.size(), width_ - 1 ) );
   if( discard_cc ) discard_control_c();
   int key;
@@ -848,7 +867,7 @@ Screen::Keys Screen::convert_key( const int key )
 
 int Screen::function_key( const int key )
   {
-  if( key >= KEY_F(1) && key <= KEY_F(12) ) return ( key - KEY_F(0) );
+  if( key >= KEY_F(1) && key <= KEY_F(12) ) return key - KEY_F(0);
   return -1;
   }
 
@@ -870,7 +889,7 @@ const char * Screen::cut_filename( const std::string & filename,
 
 int Screen::user_loop( const char * const version_msg )
   {
-  show_message( version_msg );
+  show_message( version_msg, false, false, true, false );
   int retval = -1;
   bool force_refresh = false;
   while( true )
@@ -884,7 +903,7 @@ int Screen::user_loop( const char * const version_msg )
     { Window & w = Window_vector::curwin();
     switch( key )
       {
-      case  0: msg = Block::toggle_marking( w.buffer(), w.pointer() );
+      case  0: msg = Block::toggle_marking( w.buffer_handle(), w.pointer() );
                break;						// ^SPACE
       case  2: msg = Window_vector::reformat_paragraph(); break;	// ^B
       case  3: if( !Window_vector::close( true ) ) retval = 0; break;	// ^C
@@ -926,11 +945,11 @@ int Screen::user_loop( const char * const version_msg )
       case KEY_LEFT : w.goto_pprev(); break;
       case KEY_RIGHT: w.goto_pnext(); break;
       default       : if( key == '\n' ) force_refresh = true;
-                      msg = Window_vector::add_char( key );
+                      msg = maybe_add_char( key );
       } }
     if( retval >= 0 ) break;
     { Window & w = Window_vector::curwin();
-    if( Block::follow_marking( w.buffer(), w.pointer() ) )
+    if( Block::follow_marking( w.buffer_handle(), w.pointer() ) )
       repaint( &w.buffer() ); }
     if( msg ) show_message( msg );
     }
