@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2023 Antonio Diaz Diaz.
+   Copyright (C) 2005-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -63,13 +63,14 @@ void restore_lines_and_cursor();
 
 void out_buffer_line( const Buffer & buffer, Point c, const int line );
 bool out_line( const std::string & s, const int line, const bool shift = false,
-               const char mode = 0 );
+               const char mode = 0 );	// mode: bold, inverse, raw, underline
 bool out_menu_line( const std::string & s, const int line,
                     const int hbegin = -1, const int hend = -1 );
 void repaint( const Buffer * const bufp = 0 );
 void show_feedback( const std::string & s );
 int show_message( const std::string & s, const bool get_key = false,
-                  const bool take_cursor = false, const bool discard_cc = true );
+                  const bool take_cursor = false, const bool discard_cc = true,
+                  const bool raw = true );
 void show_status_lines( const Buffer * const bufp = 0 );
 
 Keys convert_key( const int key );
