@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2023 Antonio Diaz Diaz.
+   Copyright (C) 2005-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -45,14 +45,6 @@ Point Window::clock_position() const
   { return Point( top_line_, Screen::width() - 20 ); }
 
 
-Point Window::relative_cursor() const	// cursor position on window
-  { return bhp->cursor - bhp->top_left; }
-
-
-Point Window::absolute_cursor() const	// cursor position on screen
-  { return relative_cursor() + Point( top_line_ + 1, 0 ); }
-
-
 void Window::center_cursor()
   {
   bhp->top_left.line = bhp->buffer().lines();
@@ -478,11 +470,12 @@ const char * Window::show_utf8_code()
 void Window::show_status_line( const char * const prefix ) const
   {
   if( top_line_ < 0 ) return;
-  const Buffer & buffer = bhp->buffer();
+  const Buffer_handle & bh = *bhp;
+  const Buffer & buffer = bh.buffer();
   int bufsize = 0;
   char * const buf = Screen::line_buf( &bufsize );
   int offset = bufsize - 41;
-  const long line = bhp->pcursor.line + 1, col = bhp->pcursor.col + 1;
+  const long line = bh.pcursor.line + 1, col = bh.pcursor.col + 1;
   for( long i = line; i > 9999; i /= 10 ) --offset;
   for( long i = col; i > 999; i /= 10 ) --offset;
   const char * name = buffer.nename().c_str();
@@ -490,7 +483,7 @@ void Window::show_status_line( const char * const prefix ) const
   if( overlap > 0 ) name += overlap;
   const bool modified = buffer.modified();
   const int len = snprintf( buf, offset + 1, "%-3s %c%c%c%c%c%c %s%s",
-                            prefix ? prefix : "   ",
+                            prefix ? prefix : bh.top_left.col ? "<  " : "   ",
                             buffer.options.overwrite ? 'O' : 'I',
                             buffer.options.word_wrap ? 'W' : ' ',
                             buffer.options.auto_indent ? 'A' : ' ',
@@ -507,7 +500,7 @@ void Window::show_status_line( const char * const prefix ) const
     offset = bufsize - 13;
     if( RC::editor_options().show_code_lpos == 1 )
       {
-      const int ch = buffer[bhp->pointer];
+      const int ch = buffer[bh.pointer];
       if( ch >= 0 )
         snprintf( buf + offset, bufsize - offset, "%3d(0x%02X)", ch, ch );
       else
@@ -539,8 +532,7 @@ void Window::update_points( const Point & to, const bool show,
     {
     case from_top_left:
       {
-      const Point dif = c - tl;
-      tl = to; tl.cut(); c = tl + dif; p = buffer.to_pointer( c, pc );
+      tl = to; tl.cut(); c += tl - old_tl; p = buffer.to_pointer( c, pc );
       center = false;
       break;
       }
@@ -555,17 +547,17 @@ void Window::update_points( const Point & to, const bool show,
                   height_ - ( ( c.line >= buffer.last_line() ) ? 2 : 3 );
     tl.line = std::max( 0L, c.line - d );
     }
-  else if( rc.line < 1 )
+  else if( rc.line < 0 )
     {
-    const int d = center ? ( height_ - 2 ) / 2 : 1;
+    const int d = center ? ( height_ - 2 ) / 2 : 0;
     tl.line = std::max( 0L, c.line - d );
     }
   const int ahead = std::max( 1L, std::min( 8L,
                                   buffer.characters( p.line ) - p.col ) );
   if( rc.col + ahead > Screen::width() || center )
     tl.col = std::max( 0L, c.col + ahead - Screen::width() );
-  else if( rc.col < 8 )
-    tl.col = std::max( 0L, c.col - 8 );
+  else if( rc.col < 0 )
+    tl.col = std::max( 0L, c.col );
 
   if( show ) { if( tl == old_tl ) show_status_line(); else repaint(); }
   }
