@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2023 Antonio Diaz Diaz.
+   Copyright (C) 2005-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -20,7 +20,8 @@ class Window
   Buffer_handle * bhp;
   int top_line_, height_;	// top line and height of window on screen
 
-  Point relative_cursor() const;	// cursor position on window
+  Point relative_cursor() const		// cursor position on window
+    { return bhp->cursor - bhp->top_left; }
 
 public:
   enum { min_height = 4 };
@@ -31,7 +32,8 @@ public:
   Point & pointer() const { return bhp->pointer; }
 
   Point clock_position() const;
-  Point absolute_cursor() const;	// cursor position on screen
+  Point absolute_cursor() const		// cursor position on screen
+    { return relative_cursor() + Point( top_line_ + 1, 0 ); }
   int height() const { return height_; }
   int top_line() const { return top_line_; }
 
