@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2023 Antonio Diaz Diaz.
+   Copyright (C) 2005-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -88,7 +88,7 @@ bool rectangular_block()
 bool read_only( const Buffer & buffer )
   {
   if( buffer.options.read_only )
-    { Screen::show_message( "Read only" ); return true; }
+    { Screen::show_message( rdonly_msg ); return true; }
   return false;
   }
 
@@ -236,6 +236,9 @@ bool deescapize_string( const std::string & in, std::string & out,
       if( in[i] == ']' ) out += in[i++];	// first character in set
       in_set = true; continue;
       }
+    if( ch == '=' )				// equivalence class
+      { if( i + 2 >= in.size() ) return false;
+        out += in[i++]; out += in[i++]; out += in[i++]; continue; }
     int len, code = ISO_8859::escape( in, i + 1, &len, !in_set && !plus );
     if( code < 0 )
       { if( in_set || code != -1 ) return false;
@@ -496,18 +499,7 @@ void Window_vector::prev()
 const char * Window_vector::add_char( const int key, const bool force )
   {
   Window & w = curwin();
-  if( w.buffer().options.read_only )
-    {
-    if( !force ) switch( key )			// basic less emulation
-      {
-      case ' ': w.move_vertical( w.height() - 2 ); return 0;
-      case '/': return search( 6 );				// ^F
-      case 'n': return search( 7, true, "", 0 );		// ^G -->
-      case 'N': return search( 7, true, "", 1 );		// ^G <--
-      }
-    read_only( w.buffer() );			// show feedback
-    return 0;
-    }
+  if( read_only( w.buffer() ) ) return 0;
 
   if( key >= 0 && key < 256 &&
       ( force || key == '\t' || key == '\n' || ISO_8859::isprint( key ) ) )
@@ -594,7 +586,8 @@ const char * Window_vector::read_block()
     return 0;
   try {
     Buffer tmp( name.c_str() );
-    if( tmp.empty() ) throw Buffer::Error( "File not found" );
+    if( tmp.empty() )
+      throw Buffer::Error( tmp.existed ? "File is empty" : "File not found" );
     Point p = w.pointer();
     if( w.buffer().pputb( p, tmp, tmp.bof(), tmp.eof() ) )
       Screen::repaint( &w.buffer() );
@@ -832,11 +825,12 @@ const char * Window_vector::reformat_block()
           else { w.repaint(); return e.msg; } }	// remove feedback
       cursor.line = buffer.eop( cursor ).line;	// end of paragraph, keep col
       }
+  if( change && !msg ) cursor.line = buffer.bop( Block::begin() ).line;
+  if( RC::editor_options().auto_unmark ) Block::reset();
   if( change )
     {
     buffer.reset_appendable();
     Screen::repaint( &buffer );
-    if( !msg ) cursor.line = buffer.bop( Block::begin() ).line;
     w.update_points( cursor, true, false, Window::from_cursor );
     }
   else { w.repaint();				// remove feedback
@@ -847,6 +841,7 @@ const char * Window_vector::reformat_block()
 
 /* Can't use to_lowercase, etc, because of rectangle mode.
    Can't change characters in place because of atomic undo.
+   Keep in sync with Basic_buffer::capitalize.
 */
 const char * Window_vector::change_case( const int caps_level )
   {
@@ -857,7 +852,7 @@ const char * Window_vector::change_case( const int caps_level )
   Basic_buffer tmp;
   Point p = tmp.bof();
   bool change = false;
-  bool prev_is_alnum = false;
+  bool prev_is_whitespace = true;
   for( Point p1 = Block::begin(); p1 < Block::end(); )
     {
     const bool in_block = Block::in_block( buffer, p1 );
@@ -869,13 +864,13 @@ const char * Window_vector::change_case( const int caps_level )
       case 1: if( in_block && ISO_8859::islower( ch ) )
                 { ch = ISO_8859::toupper( ch ); change = true; } break;
       case 2: {
-              if( !in_block ) { prev_is_alnum = false; break; }
-              const bool is_alnum = ISO_8859::isalnum_( ch );
-              if( prev_is_alnum && ISO_8859::isupper( ch ) )
-                { ch = ISO_8859::tolower( ch ); change = true; }
-              if( !prev_is_alnum && ISO_8859::islower( ch ) )
+              if( !in_block ) { prev_is_whitespace = true; break; }
+              const bool is_whitespace = ISO_8859::isspace( ch );
+              if( prev_is_whitespace && ISO_8859::islower( ch ) )
                 { ch = ISO_8859::toupper( ch ); change = true; }
-              prev_is_alnum = is_alnum;
+              if( !prev_is_whitespace && ISO_8859::isupper( ch ) )
+                { ch = ISO_8859::tolower( ch ); change = true; }
+              prev_is_whitespace = is_whitespace;
               }
       }
     tmp.pputc( p, ch );
@@ -1228,11 +1223,11 @@ const char * Window_vector::search( const int abort_key, const bool again,
   static std::vector< std::string > options_history;
   static std::string search_string;		// deescapized search string
   static std::string replace_string;		// deescapized replace string
+  static int replace = 0;			// 1 = replace, 2 = delete
   static bool backward_opt = false;
   static bool block = false;
   static bool global = false;
   static bool icase = false;
-  static bool replace = false;
 
   if( !again || search_string.empty() )
     {
@@ -1249,12 +1244,12 @@ const char * Window_vector::search( const int abort_key, const bool again,
       { search_string.clear(); return "Syntax error in search string"; }
     std::string prompt;
     if( RC::editor_options().ignore_case )
-      prompt = "(N)o_ignore_case (R)eplace (B)ackwards (G)lobal Bloc(K) (^C to abort): ";
-    else prompt = "(I)gnore_case (R)eplace (B)ackwards (G)lobal Bloc(K) (^C to abort): ";
+      prompt = "(N)o_icase (R)eplace (D)elete (B)ackwards (G)lobal Bloc(K) (^C to abort): ";
+    else prompt = "(I)case (R)eplace (D)elete (B)ackwards (G)lobal Bloc(K) (^C to abort): ";
     options_history.push_back( std::string() );
     size = Screen::get_string( prompt, options_history, abort_key );
     if( size < 0 ) return 0;
-    backward_opt = false; block = false; global = false; replace = false;
+    replace = 0; backward_opt = false; block = false; global = false;
     icase = RC::editor_options().ignore_case;
     if( size > 0 )
       {
@@ -1263,24 +1258,28 @@ const char * Window_vector::search( const int abort_key, const bool again,
         switch( ISO_8859::toupper( options[i] ) )
           {
           case 'B': backward_opt = true; break;
+          case 'D': replace = 2; break;			// delete
           case 'G': global = true; break;
           case 'I': icase = true; break;
           case 'K': block = true; break;
           case 'N': icase = false; break;
-          case 'R': replace = true; break;
+          case 'R': replace = 1; break;			// replace
           }
       }
     if( block ) global = false;
-    if( replace )
+    if( replace != 0 )			// replace or delete
       {
       replace_string.clear();		// by default replace with nothing
-      replace_history.push_back( std::string() );
-      size = Screen::get_string( "Replace with (^C to abort): ",
-                                 replace_history, abort_key );
-      if( size < 0 ) { replace = false; return 0; }
-      if( size > 0 &&
-          !deescapize_string( replace_history.back(), replace_string, false ) )
-        { search_string.clear(); return "Syntax error in replace string"; }
+      if( replace == 1 )
+        {
+        replace_history.push_back( std::string() );
+        size = Screen::get_string( "Replace with (^C to abort): ",
+                                   replace_history, abort_key );
+        if( size < 0 ) { replace = 0; return 0; }	// aborted
+        if( size > 0 &&
+            !deescapize_string( replace_history.back(), replace_string, false ) )
+          { search_string.clear(); return "Syntax error in replace string"; }
+        }
       }
     }
   if( toggle == 2 ) backward_opt = !backward_opt;	// toggle permanently
@@ -1324,7 +1323,7 @@ const char * Window_vector::search( const int abort_key, const bool again,
           ( p1.col < Block::begin().col || p2.col > Block::end().col ) )
         { ++i; found = false; continue; }
       found_any = true;
-      if( !replace ) { w.update_points( p, true, true ); break; }
+      if( replace == 0 ) { w.update_points( p, true, true ); break; }
       Block::save_block_position(); w.update_points( p, false, true );
       if( ask )
         {
@@ -1366,7 +1365,7 @@ const char * Window_vector::search( const int abort_key, const bool again,
           else
             {
             prev_replace = 0; w.buffer().reset_appendable();
-            if( w.buffer().options.read_only ) msg = "Read only";
+            if( w.buffer().options.read_only ) msg = rdonly_msg;
             else msg = "Replace error: check syntax";
             }
           break;
